@@ -18,7 +18,7 @@ my %params = (
     PREREQ_PM     => {
     },
     BUILD_REQUIRES => {
-        'Test::More'          => '0.47',
+        'Test::More'          => '0.88', # done_testing
         'Test::UseAllModules' => '0.10',
     },
     META_MERGE => {
@@ -28,7 +28,7 @@ my %params = (
     },
 );
 
-my $eumm = $ExtUtils::MakeMaker::VERSION;
+my $eumm = eval $ExtUtils::MakeMaker::VERSION;
 delete $params{LICENSE}          if $eumm < 6.31;
 delete $params{MIN_PERL_VERSION} if $eumm < 6.48;
 delete $params{META_MERGE}       if $eumm < 6.46;
